@@ -26,7 +26,7 @@ class KWEATHERCORE_EXPORT PendingWeatherForecast : public Reply
 {
     Q_OBJECT
 public:
-    ~PendingWeatherForecast();
+    ~PendingWeatherForecast() override;
 
     /**
      * value pointer to the shared weather data
@@ -34,18 +34,12 @@ public:
      * @return
      */
     WeatherForecast value() const;
-    /**
-     * isFinished if the call has finished
-     * @deprecated No longer needed, finished() is emitted in all cases now.
-     */
-    [[deprecated("no longer needed")]] bool isFinished() const;
 
 private:
     friend class WeatherForecastSource;
     explicit PendingWeatherForecast(double latitude,
                                     double longitude,
                                     const QString &timezone,
-                                    const std::vector<Sunrise> &sunrise,
                                     QNetworkAccessManager *nam,
                                     QObject *parent = nullptr);
     explicit PendingWeatherForecast(WeatherForecast data, QObject *parent = nullptr);
